from control import Control

class GitbucketControl:
    def __init__(self):
        self.control = Control()

    def enable(self):
        self.control.enable()
        self.control.start()

    def disable(self):
        self.control.disable()
        self.control.remove_service()

    def status(self):
        return self.control.is_active()